﻿local addonName, L = ...;

--[[

    flagRSP profile support as plugin for flagRSP

    Handles:
        - Saving of profiles
		- Loading of profiles
        - Deleting of profiles
    GUI: TODO
		- Adds Profiletab-GUI to flagRSP book
            - Displays list of profiles
            - Displays profile description
            - Add-Button
            - Delete-Button
            - Save-Button
            - Load-Button
        - Uses InfoBox for displaying profile content

    Author: Syeira (EU-Forscherliga), 09-2012
    
]]--


-- Public variables
FlagRSPProfiles = {
	debug = true,
};


-- Saved variables
FlagRSPProfilesData = {
	profiles = {},
}


-- Private variables
local addonNameFull = "FlagRSP Profiles";
local verMajor , verMinor , verPatch  = 1, 0, 0; -- version of FlagRSP Profiles
local verMajorM, verMinorM, verPatchM = 1, 2, 0; -- compatible FlagRSP MoP version
local correctFlagRSP = true;


-- Constants
local COLOR_HIGHLIGHT = "FFffff80";
local COLOR_CHATCOMMAND = "FFBD70FF";


--[[ == Local functions ======================================================================= ]]--

local function checkVersion()
    if ( verMajorM > FlagRSP.verMajor ) then
        return false;
    elseif ( verMinorM > FlagRSP.verMinor ) then
        return false;
    elseif ( verPatchM > FlagRSP.verPatch ) then
        return false;
    else
        return true
    end
end


--[[ == Profiles ============================================================================== ]]--

function FlagRSPProfiles:OnEvent_Load()
    if ( not checkVersion() ) then
        local msg = L.MSG_WRONGVER;
        msg = gsub(msg, "#addonName#", addonNameFull);
        msg = gsub(msg, "#verprofiles#", verMajor.."."..verMinor.."."..verPatch);
        msg = gsub(msg, "#verflag#", verMajorM ..".".. verMinorM..".".. verPatchM);
        FlagRSPProfiles:printM("|cFFff0000"..msg.."|r");
        correctFlagRSP = false;
    else
        local msg = L.MSG_LOADED;
        msg = gsub(msg, "#addonName#", addonNameFull);
        msg = gsub(msg, "#addonVersion#", verMajor.."."..verMinor.."."..verPatch);
        FlagRSPProfiles:printM(msg);
        FlagRSPProfiles:printM(gsub(L.MSG_SEEHELP,"#command#","|c" .. COLOR_CHATCOMMAND .. " /rspprofiles help|r"));
    end
end

function FlagRSPProfiles:saveProfile( profilename, desc )
	if ( profilename ~= nil and strtrim(profilename) ~= "") then
		if ( strfind(profilename,"^[0-9a-zA-Z_]*$") == nil ) then
            return false;
		end
		if ( desc == nil ) then
			desc = "";
		end
		FlagRSPProfilesData.profiles[profilename] = {};
		FlagRSPProfilesData.profiles[profilename] = {
			profile     = profilename,
			profileDesc = strtrim(desc),

			fullname = FlagRSPConfigure:GetFullname(),
			title    = FlagRSPConfigure:GetTitle(),
			desc     = FlagRSPConfigure:GetDescription(),
			
			flagRP   = FlagRSPConfigure:GetRPFlag(),
			flagChar = FlagRSPConfigure:GetCharacterStatus(),
		};
		return true;
	else
		return false;
	end
end

function FlagRSPProfiles:loadProfile( name )
	if ( FlagRSPProfilesData.profiles[name] ~= nil ) then
		local p = FlagRSPProfilesData.profiles[name];

        FlagRSPConfigure:SetFullname(p.fullname);
        FlagRSPConfigure:SetTitle(p.title);
        FlagRSPConfigure:SetDescription(p.desc);

        FlagRSPConfigure:SetRPFlag(p.flagRP);
        FlagRSPConfigure:SetCharacterStatus(p.flagChar);

        FriendlistCharFrame_Load();
        FlagRSPProtocol:UpdateOwn();

		return true
	else
		return false;
	end
end

function FlagRSPProfiles:deleteProfile( name )
	if ( name ~= nil and strtrim(name) ~= "" ) then
		FlagRSPProfilesData.profiles[name] = nil;
		return true;
	else
		return false;
	end
end

function FlagRSPProfiles:clearProfiles()
    FlagRSPProfilesData.profiles = {};
end

function FlagRSPProfiles:listProfiles()
	FlagRSPProfiles:printM(L.MSG_PRINTLIST);
    local msg = "";
	for k,v in pairs(FlagRSPProfilesData.profiles) do
        msg = "    " .. "\"" .. v.profile .."\""
		if ( v.profileDesc ~= "" ) then
			msg = msg .. ":  " .. v.profileDesc;
		end
        FlagRSPProfiles:printM(msg);
	end
end

function FlagRSPProfiles:printM(msg)
	DEFAULT_CHAT_FRAME:AddMessage("|c" .. COLOR_HIGHLIGHT .. "<flagRSP Profile>|r " .. msg,1,1,1);
end


--[[ == Chat commands ========================================================================= ]]--

SlashCmdList['FLAGRSPPROFILE_SLASHCMD'] = function( msg, ... )
    if ( not correctFlagRSP ) then
        local msg = L.MSG_WRONGVER;
        msg = gsub(msg, "#addonName#", addonNameFull);
        msg = gsub(msg, "#verprofiles#", verMajor.."."..verMinor.."."..verPatch);
        msg = gsub(msg, "#verflag#", verMajorM ..".".. verMinorM..".".. verPatchM);
        FlagRSPProfiles:printM("|cFFff0000"..msg.."|r");
        return;
    end

    local command, args = msg:match("^(%S*)%s*(.-)$");

    command = strlower(command);
    args = strtrim(args);

    -- Main Commands
	local result = false;
    if ( command == "load" ) then
		result = FlagRSPProfiles:loadProfile( args );
		if ( result ) then
			FlagRSPProfiles:printM(gsub(L.MSG_LOADEDPROFILE, "#profilename#", args));
		else
			FlagRSPProfiles:printM(gsub(L.MSG_LOADEDPROFILE_ERROR, "#profilename#", args));
		end
		
    elseif ( command == "save" ) then
		local name, desc = strsplit(" ", args, 2);
		result = FlagRSPProfiles:saveProfile( name, desc );
		if ( result ) then
			FlagRSPProfiles:printM(gsub(L.MSG_SAVEDPROFILE, "#profilename#", name));		
		else
			FlagRSPProfiles:printM(gsub(L.MSG_SAVEDPROFILE_ERROR, "#profilename#", name));		
		end
		
	elseif ( command == "delete" ) then
		result = FlagRSPProfiles:deleteProfile( args );
		if ( result ) then
			FlagRSPProfiles:printM(gsub(L.MSG_DELETEDPROFILE, "#profilename#", args));		
		else
			FlagRSPProfiles:printM(gsub(L.MSG_DELETEDPROFILE_ERROR, "#profilename#", args));		
		end
        
    elseif ( command == "clearall" ) then
        FlagRSPProfiles:clearProfiles();
        FlagRSPProfiles:printM(L.MSG_DELETEDALL);
		
	elseif ( command == "list" ) then
        FlagRSPProfiles:listProfiles();
		
    -- help commands
    elseif ( command == "help" or command == "?" ) then
        local txt = L.MSG_CHATCOMMANDS;
        txt = gsub(txt, "#addonName#", addonNameFull);
        txt = gsub(txt, "#addonVersion#", verMajor.."."..verMinor.."."..verPatch);
        FlagRSPProfiles:printM(txt .. ":");
        FlagRSPProfiles:printM("|c"..COLOR_CHATCOMMAND.."    /rspprofiles, /rspp|r");
        FlagRSPProfiles:printM("|c"..COLOR_CHATCOMMAND.."    /rspp help    |r" .. L.HELP_HELP .. "");
        FlagRSPProfiles:printM("|c"..COLOR_CHATCOMMAND.."    /rspp load name    |r" .. L.HELP_LOAD .. "");
        FlagRSPProfiles:printM("|c"..COLOR_CHATCOMMAND.."    /rspp save name description    |r" .. L.HELP_SAVE .. "");
        FlagRSPProfiles:printM("|c"..COLOR_CHATCOMMAND.."    /rspp delete name    |r" .. L.HELP_DELETE .. "");
        FlagRSPProfiles:printM("|c"..COLOR_CHATCOMMAND.."    /rspp list    |r" .. L.HELP_LIST .. "");
        FlagRSPProfiles:printM("    "..L.HELP_INFO);

    else
        FlagRSPProfiles:printM(gsub(L.MSG_COMMANDERROR,"#command#","|c" .. COLOR_CHATCOMMAND .. " /rspprofiles help|r"));
    end
end
SLASH_FLAGRSPPROFILE_SLASHCMD1 = '/rspprofiles';
SLASH_FLAGRSPPROFILE_SLASHCMD1 = '/rspp';